@@ -120,7 +120,7 @@ def _offsetLinkGeometry(link_dict, width_of_lane, GT):
         reversed_link_found = False
         for link_id_b in link_ids[link_no_a+1:]:
             link_b = link_dict[link_id_b]
-            if geometry_xy_a_r.almost_equals(link_b.geometry_xy, decimal=1):
+            if geometry_xy_a_r.equals_exact(link_b.geometry_xy, tolerance=0.1):
                 reversed_link_found = True
                 link_offset_dict[link_a] = True
                 link_offset_dict[link_b] = True
@@ -251,7 +251,6 @@ def _cutMacroLinks(link_dict, GT):
 
 
 def _autoGenerateMovements(macronet):
-    macronet.movement_generated = True
 
     max_movement_id = macronet.max_movement_id
     for macronode_id, macronode in macronet.node_dict.items():
@@ -263,18 +262,20 @@ def _autoGenerateMovements(macronet):
     macronet.max_movement_id = max_movement_id
 
 
-def buildMultiResolutionNets(macronet, auto_movement_generation=True, connector_type=None,
+def buildMultiResolutionNets(macronet, auto_movement_generation=True, exclusive_bike_walk_lanes=True, connector_type=None,
                              width_of_lane=3.5, length_of_cell=7.0):
     """
-    Build multi-resolution networks from the source network
+    Build the corresponding mesoscopic and microscopic networks for a source (macroscopic) network
 
     Parameters
     ----------
     macronet: Network
-        soucrce macroscopic network
+        a soucrce osm2gmns Network object
     auto_movement_generation: bool
-        automatically generate movements for intersections without movement information. If auto_movement_generation is
-        set as False, movements at intersections without movement information will not be generated
+        automatically generate movements for intersections without movement information by calling function generateMovements
+        in osm2gmns. if auto_movement_generation is set as False, movements at intersections without movement information will not be generated
+    exclusive_bike_walk_lanes: bool
+        build exclusive lanes for bike and walk
     connector_type: int
         link_type of connectors
     width_of_lane: float
@@ -284,6 +285,7 @@ def buildMultiResolutionNets(macronet, auto_movement_generation=True, connector_
 
     Returns
     -------
+    None
 
     """
     if og_settings.verbose:
@@ -299,7 +301,7 @@ def buildMultiResolutionNets(macronet, auto_movement_generation=True, connector_
     if auto_movement_generation:
         _autoGenerateMovements(macronet)
 
-    net_generator = NetGenerator(macronet, length_of_cell, width_of_lane)
+    net_generator = NetGenerator(macronet, exclusive_bike_walk_lanes, length_of_cell, width_of_lane)
     net_generator.generateNet()
     macronet.mesonet = net_generator.mesonet
     macronet.micronet = net_generator.micronet
\ No newline at end of file
