@@ -232,7 +232,7 @@ def _preprocessWays(osmnetwork, link_types, network_types):
     include_aeroway = True if 'aeroway' in network_types_set else False
 
     for osm_way_id, way in osmnetwork.osm_way_dict.items():
-        if way.building or way.amenity:
+        if way.building or way.amenity or way.leisure:
             POI_way_list.append(way)
 
         elif way.highway:
@@ -263,7 +263,7 @@ def _preprocessWays(osmnetwork, link_types, network_types):
             way.allowable_agent_type_list = list(set(allowable_agent_type_list).intersection(network_types_set))
             if len(way.allowable_agent_type_list) == 0:
                 continue
-            way.allowed_uses = ';'.join(way.allowable_agent_type_list)
+            way.allowed_uses = way.allowable_agent_type_list
 
             way.ref_node_list[0].is_crossing = True
             way.ref_node_list[-1].is_crossing = True
@@ -356,11 +356,15 @@ def _createNLPs(osmnetwork, network, link_types, offset, network_types, POI, POI
 
 
 
-def _buildNet(osmnetwork, network_types, link_types, POI, POI_percentage, offset, min_nodes, combine, default_lanes, default_speed, default_capacity):
+def _buildNet(osmnetwork, network_types, link_types, POI, POI_percentage, offset, min_nodes, combine, default_lanes,
+              default_speed, default_capacity, start_node_id, start_link_id):
     if og_settings.verbose:
         print('  parsing osm network')
 
     network = Network()
+    network.max_node_id = start_node_id
+    network.max_link_id = start_link_id
+
     network.GT, network.bounds = osmnetwork.GT, osmnetwork.bounds
 
     # update default lanes, speed, and capacity
@@ -381,6 +385,10 @@ def _buildNet(osmnetwork, network_types, link_types, POI, POI_percentage, offset
 def getNetFromOSMFile(osm_filename='map.osm', network_types=('auto',), link_types='all', POI=False, POI_sampling_ratio=1.0,
                       strict_mode=True, offset='no', min_nodes=1, combine=False, bbox=None,
                       default_lanes=False, default_speed=False, default_capacity=False):
+    """
+    Deprecated
+    """
+
     print('WARNING: getNetFromOSMFile() and getNetFromPBFFile() are deprecated and will be removed in a future release.\n'
           '         Please use getNetFromFile().')
 
@@ -392,6 +400,9 @@ def getNetFromOSMFile(osm_filename='map.osm', network_types=('auto',), link_type
 def getNetFromPBFFile(pbf_filename='map.osm.pbf', network_types=('auto',), link_types='all', POI=False, POI_sampling_ratio=1.0,
                       strict_mode=True, offset='no', min_nodes=1, combine=False, bbox=None,
                       default_lanes=False, default_speed=False, default_capacity=False):
+    """
+    Deprecated
+    """
 
     print('WARNING: getNetFromOSMFile() and getNetFromPBFFile() are deprecated and will be removed in a future release.\n'
           '         Please use getNetFromFile().')
@@ -402,7 +413,56 @@ def getNetFromPBFFile(pbf_filename='map.osm.pbf', network_types=('auto',), link_
 
 def getNetFromFile(filename='map.osm', network_types=('auto',), link_types='all', POI=False, POI_sampling_ratio=1.0,
                    strict_mode=True, offset='no', min_nodes=1, combine=False, bbox=None,
-                   default_lanes=False, default_speed=False, default_capacity=False):
+                   default_lanes=False, default_speed=False, default_capacity=False, start_node_id=0, start_link_id=0):
+    """
+    Get an osm2gmns Network object from an osm file
+
+    Parameters
+    ----------
+    filename: str
+        path of an osm file; can be absolute or relative path; supported osm file formats: .osm, .xml, and .pbf
+    network_types: str, tuple of strings, list of strings, or set of strings
+        osm2gmns supports five different network types, including auto, bike, walk, railway, and aeroway.
+        network_types can be any one or any combinations of the five supported network types
+    link_types: str, tuple of strings, list of strings, or set of strings
+        supported link types: motorway, trunk, primary, secondary, tertiary, residential, service, cycleway,
+        footway, track, unclassified, connector, railway, and aeroway.
+    POI: bool
+        if extract point of interest information
+    POI_sampling_ratio: float
+        prcentage of POIs to be extracted if POI is set as True. this value should be a float number between 0.0 and 1.0.
+    strict_mode: bool
+        if True, network elements (node, link, poi) outside the boundary will be discarded
+    offset: str
+        offset overlapping links. the value of this argument can be 'left', 'right', or 'no'
+    min_nodes: int
+        a network return by the function may contain several sub-networks that are disconnected from each other.
+        sub-networks with the number of nodes less than min_nodes will be discarded
+    combine: bool
+        if True, adhacent short links with the same attributes will be combined into a long link. the operation will only
+        be performed on short links connected with a two-degree nodes (one incoming link and one outgoing link)
+    bbox: tuple of four float/int values, list of four float/int values, None
+        specify the boundary of the network to be extracted, consisting of minimum latitude, minimum longtitude, maximum latitude, and maximum longitud.
+        if None, osm2gmns will try to find network boundary from the input osm file
+    default_lanes: bool, dict
+        if True, assign a default value for links without lanes information based on built-in settings. if a dict,
+        assign a default value for links without lanes information based on the dict passed by users.
+    default_speed: bool, dict
+        if True, assign a default value for links without speed information based on built-in settings. if a dict,
+        assign a default value for links without speed information based on the dict passed by users.
+    default_capacity: bool, dict
+        if True, assign a default value for links without capacity information based on built-in settings. if a dict,
+        assign a default value for links without capacity information based on the dict passed by users.
+    start_node_id: int
+        osm2gmns assigns node_ids to generated nodes starting from start_node_id.
+    start_link_id: int
+        osm2gmns assigns link_ids to generated links starting from start_link_id
+
+    Returns
+    -------
+    network: Network
+        osm2gmns Network object
+    """
 
     if og_settings.verbose:
         print('arguments used for network parsing:')
@@ -418,19 +478,22 @@ def getNetFromFile(filename='map.osm', network_types=('auto',), link_types='all'
         print(f'  bbox: {bbox}')
         print(f'  default_lanes: {default_lanes}')
         print(f'  default_speed: {default_speed}')
-        print(f'  default_capacity: {default_capacity}\n')
+        print(f'  default_capacity: {default_capacity}')
+        print(f'  start_node_id: {start_node_id}')
+        print(f'  start_link_id: {start_link_id}\n')
 
         print('Building Network from OSM file')
 
     network_types_, link_types_, POI_, POI_sampling_ratio_, strict_mode_, offset_, min_nodes_, combine_, \
-        bbox_, default_lanes_, default_speed_, default_capacity_ = \
+        bbox_, default_lanes_, default_speed_, default_capacity_, start_node_id_, start_link_id_ = \
         checkArgs_getNetFromFile(filename, network_types, link_types, POI, POI_sampling_ratio, strict_mode, offset,
-                                min_nodes, combine, bbox, default_lanes, default_speed, default_capacity)
+                                min_nodes, combine, bbox, default_lanes, default_speed, default_capacity, start_node_id,
+                                 start_link_id)
 
     osmnetwork = readOSMFile(filename, POI_, strict_mode_, bbox_)
 
     network = _buildNet(osmnetwork, network_types_, link_types_, POI_, POI_sampling_ratio_, offset_, min_nodes_, combine_,
-                        default_lanes_, default_speed_, default_capacity_)
+                        default_lanes_, default_speed_, default_capacity_, start_node_id_, start_link_id_)
 
     if og_settings.verbose:
         print(f'  number of nodes: {len(network.node_dict)}, number of links: {len(network.link_dict)}, number of pois: {len(network.POI_list)}')
