@@ -25,6 +25,7 @@ osm_highway_type_dict = {'motorway': ('motorway', False),
                          'tertiary_link': ('tertiary', True),
                          'residential': ('residential', False),
                          'residential_link': ('residential', True),
+                         'living_street': ('living_street', False),
                          'service': ('service', False),
                          'services': ('service', False),
                          'cycleway': ('cycleway', False),
@@ -34,19 +35,19 @@ osm_highway_type_dict = {'motorway': ('motorway', False),
                          'track': ('track', False),
                          'unclassified': ('unclassified', False)}
 
-link_type_no_dict = {'motorway':1, 'trunk':2, 'primary':3, 'secondary':4, 'tertiary':5, 'residential':6, 'service':7,
-                     'cycleway':8, 'footway':9, 'track':10, 'unclassified':11, 'connector':20, 'railway':30, 'aeroway':31}
+link_type_no_dict = {'motorway':1, 'trunk':2, 'primary':3, 'secondary':4, 'tertiary':5, 'residential':6, 'living_street':7, 'service':8,
+                     'cycleway':9, 'footway':10, 'track':11, 'unclassified':15, 'connector':20, 'railway':30, 'aeroway':31}
 
-default_lanes_dict = {'motorway': 4, 'trunk': 3, 'primary': 3, 'secondary': 2, 'tertiary': 2, 'residential': 1, 'service': 1,
+default_lanes_dict = {'motorway': 4, 'trunk': 3, 'primary': 3, 'secondary': 2, 'tertiary': 2, 'residential': 1, 'living_street':1, 'service': 1,
                       'cycleway':1, 'footway':1, 'track':1, 'unclassified': 1, 'connector': 2}
-default_speed_dict = {'motorway': 120, 'trunk': 100, 'primary': 80, 'secondary': 60, 'tertiary': 40, 'residential': 30, 'service': 30,
+default_speed_dict = {'motorway': 120, 'trunk': 100, 'primary': 80, 'secondary': 60, 'tertiary': 40, 'residential': 30, 'living_street':30, 'service': 30,
                       'cycleway':5, 'footway':5, 'track':30, 'unclassified': 30, 'connector':120}
-default_capacity_dict = {'motorway': 2300, 'trunk': 2200, 'primary': 1800, 'secondary': 1600, 'tertiary': 1200, 'residential': 1000, 'service': 800,
+default_capacity_dict = {'motorway': 2300, 'trunk': 2200, 'primary': 1800, 'secondary': 1600, 'tertiary': 1200, 'residential': 1000, 'living_street':1000, 'service': 800,
                          'cycleway':800, 'footway':800, 'track':800, 'unclassified': 800, 'connector':9999}
 
 
 default_oneway_flag_dict = {'motorway': False,'trunk':False,'primary':False,'secondary':False,'tertiary':False,
-                            'residential':False,'service':False,'cycleway':True, 'footway':True,'track': True,
+                            'residential':False,'living_street':False,'service':False,'cycleway':True, 'footway':True,'track': True,
                             'unclassified':False, 'connector':False, 'railway':True, 'aeroway':True}
 
 
